@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de">
+<TS version="2.1" language="de">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -233,6 +233,14 @@ Es wird mit einer einfachen Universalform gearbeitet.</translation>
         <comment>Choose Edit|Find from the menu bar or press Ctrl+F to pop up the Find dialog</comment>
         <translation></translation>
     </message>
+    <message>
+        <source>Obsoleted messages are skipped when checked.</source>
+        <translation>Bewirkt, dass als &apos;obsolet&apos; gekennzeichnete Texte übersprungen werden.</translation>
+    </message>
+    <message>
+        <source>Skip &amp;obsolete</source>
+        <translation>&apos;&amp;obsolet&apos; überspringen</translation>
+    </message>
 </context>
 <context>
     <name>FormMultiWidget</name>
@@ -1203,6 +1211,42 @@ Alle Dateien (*)</translation>
         <source>Display information about the Qt toolkit by Digia.</source>
         <translation>Information über das Qt-Toolkit von Digia anzeigen.</translation>
     </message>
+    <message>
+        <source>Visualize whitespace</source>
+        <translation>Leerzeichen darstellen</translation>
+    </message>
+    <message>
+        <source>Toggle visualize whitespace in editors</source>
+        <translation>Schaltet die Darstellung der Leerzeichen in den Editoren um</translation>
+    </message>
+    <message>
+        <source>&amp;Zoom</source>
+        <translation>&amp;Vergrößerung</translation>
+    </message>
+    <message>
+        <source>Increase</source>
+        <translation>Vergrößern</translation>
+    </message>
+    <message>
+        <source>Ctrl++</source>
+        <translation>Ctrl++</translation>
+    </message>
+    <message>
+        <source>Decrease</source>
+        <translation>Verkleinern</translation>
+    </message>
+    <message>
+        <source>Ctrl+-</source>
+        <translation>Ctrl+-</translation>
+    </message>
+    <message>
+        <source>Reset to default</source>
+        <translation>Standardgröße</translation>
+    </message>
+    <message>
+        <source>Ctrl+0</source>
+        <translation>Ctrl+0</translation>
+    </message>
 </context>
 <context>
     <name>MessageEditor</name>
